package cn.com.infosec.crypto.util;

import cn.com.infosec.asn1.ASN1InputStream;
import cn.com.infosec.asn1.ASN1Object;
import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.DERInteger;
import cn.com.infosec.asn1.DERObject;
import cn.com.infosec.asn1.DERObjectIdentifier;
import cn.com.infosec.asn1.DEROctetString;
import cn.com.infosec.asn1.nist.NISTNamedCurves;
import cn.com.infosec.asn1.oiw.ElGamalParameter;
import cn.com.infosec.asn1.oiw.OIWObjectIdentifiers;
import cn.com.infosec.asn1.pkcs.DHParameter;
import cn.com.infosec.asn1.pkcs.PKCSObjectIdentifiers;
import cn.com.infosec.asn1.sec.SECNamedCurves;
import cn.com.infosec.asn1.teletrust.TeleTrusTNamedCurves;
import cn.com.infosec.asn1.x509.AlgorithmIdentifier;
import cn.com.infosec.asn1.x509.DSAParameter;
import cn.com.infosec.asn1.x509.RSAPublicKeyStructure;
import cn.com.infosec.asn1.x509.SubjectPublicKeyInfo;
import cn.com.infosec.asn1.x509.X509ObjectIdentifiers;
import cn.com.infosec.asn1.x9.X962NamedCurves;
import cn.com.infosec.asn1.x9.X962Parameters;
import cn.com.infosec.asn1.x9.X9ECParameters;
import cn.com.infosec.asn1.x9.X9ECPoint;
import cn.com.infosec.asn1.x9.X9ObjectIdentifiers;
import cn.com.infosec.crypto.params.AsymmetricKeyParameter;
import cn.com.infosec.crypto.params.DHParameters;
import cn.com.infosec.crypto.params.DHPublicKeyParameters;
import cn.com.infosec.crypto.params.DSAParameters;
import cn.com.infosec.crypto.params.DSAPublicKeyParameters;
import cn.com.infosec.crypto.params.ECDomainParameters;
import cn.com.infosec.crypto.params.ECPublicKeyParameters;
import cn.com.infosec.crypto.params.ElGamalParameters;
import cn.com.infosec.crypto.params.ElGamalPublicKeyParameters;
import cn.com.infosec.crypto.params.RSAKeyParameters;
import cn.com.infosec.math.ec.ECCurve;
import cn.com.infosec.math.ec.ECPoint;
import java.io.InputStream;
import java.math.BigInteger;

public class PublicKeyFactory {
   public static AsymmetricKeyParameter createKey(byte[] keyInfoData) {
      return createKey(SubjectPublicKeyInfo.getInstance(ASN1Object.fromByteArray(keyInfoData)));
   }

   public static AsymmetricKeyParameter createKey(InputStream inStr) {
      return createKey(SubjectPublicKeyInfo.getInstance((new ASN1InputStream(inStr)).readObject()));
   }

   public static AsymmetricKeyParameter createKey(SubjectPublicKeyInfo keyInfo) {
      AlgorithmIdentifier var1;
      BigInteger keyInfo1;
      BigInteger var10;
      if (!(var1 = keyInfo.getAlgorithmId()).getObjectId().equals(PKCSObjectIdentifiers.rsaEncryption) && !var1.getObjectId().equals(X509ObjectIdentifiers.id_ea_rsa)) {
         DERInteger keyInfo2;
         BigInteger var10002;
         if (!var1.getObjectId().equals(PKCSObjectIdentifiers.dhKeyAgreement) && !var1.getObjectId().equals(X9ObjectIdentifiers.dhpublicnumber)) {
            if (var1.getObjectId().equals(OIWObjectIdentifiers.elGamalAlgorithm)) {
               ElGamalParameter var20;
               var20 = new ElGamalParameter.<init>((ASN1Sequence)keyInfo.getAlgorithmId().getParameters());
               keyInfo2 = (DERInteger)keyInfo.getPublicKey();
               var10002 = keyInfo2.getValue();
               keyInfo1 = var20.getP();
               return new ElGamalPublicKeyParameters(var10002, new ElGamalParameters(keyInfo1, var20.getG()));
            } else if (!var1.getObjectId().equals(X9ObjectIdentifiers.id_dsa) && !var1.getObjectId().equals(OIWObjectIdentifiers.dsaWithSHA1)) {
               if (var1.getObjectId().equals(X9ObjectIdentifiers.id_ecPublicKey)) {
                  X962Parameters var16;
                  X962Parameters var10000 = var16 = new X962Parameters;
                  var10000.<init>((DERObject)keyInfo.getAlgorithmId().getParameters());
                  ECPoint var3;
                  BigInteger var4;
                  BigInteger var5;
                  byte[] var6;
                  X9ECParameters var15;
                  X9ECParameters var10001;
                  ECDomainParameters var18;
                  X9ECParameters var10003;
                  ECCurve var19;
                  X9ECParameters var10004;
                  ECDomainParameters var22;
                  X9ECParameters var23;
                  if (var10000.isNamedCurve()) {
                     DERObjectIdentifier var17;
                     if ((var15 = X962NamedCurves.getByOID(var17 = (DERObjectIdentifier)var16.getParameters())) == null && (var15 = SECNamedCurves.getByOID(var17)) == null && (var15 = NISTNamedCurves.getByOID(var17)) == null) {
                        var15 = TeleTrusTNamedCurves.getByOID(var17);
                     }

                     var22 = var18 = new ECDomainParameters;
                     var10001 = var15;
                     var23 = var15;
                     var10003 = var15;
                     var10004 = var15;
                     var19 = var15.getCurve();
                     var3 = var10004.getG();
                     var4 = var10003.getN();
                     var5 = var23.getH();
                     var6 = var10001.getSeed();
                     var22.<init>(var19, var3, var4, var5, var6);
                  } else {
                     var15 = new X9ECParameters.<init>((ASN1Sequence)var16.getParameters());
                     var22 = var18 = new ECDomainParameters;
                     var10001 = var15;
                     var23 = var15;
                     var10003 = var15;
                     var10004 = var15;
                     var19 = var15.getCurve();
                     var3 = var10004.getG();
                     var4 = var10003.getN();
                     var5 = var23.getH();
                     var6 = var10001.getSeed();
                     var22.<init>(var19, var3, var4, var5, var6);
                  }

                  byte[] keyInfo3 = keyInfo.getPublicKeyData().getBytes();
                  DEROctetString var21;
                  var21 = new DEROctetString.<init>(keyInfo3);
                  X9ECPoint keyInfo4;
                  keyInfo4 = new X9ECPoint.<init>(var18.getCurve(), var21);
                  return new ECPublicKeyParameters(keyInfo4.getPoint(), var18);
               } else {
                  throw new RuntimeException("algorithm identifier in key not recognised");
               }
            } else {
               DSAParameter var13;
               var13 = new DSAParameter.<init>((ASN1Sequence)keyInfo.getAlgorithmId().getParameters());
               keyInfo2 = (DERInteger)keyInfo.getPublicKey();
               var10002 = keyInfo2.getValue();
               DSAParameter var10005 = var13;
               keyInfo1 = var13.getP();
               var10 = var13.getQ();
               BigInteger var2 = var10005.getG();
               return new DSAPublicKeyParameters(var10002, new DSAParameters(keyInfo1, var10, var2));
            }
         } else {
            DHParameter var11;
            var11 = new DHParameter.<init>((ASN1Sequence)keyInfo.getAlgorithmId().getParameters());
            keyInfo2 = (DERInteger)keyInfo.getPublicKey();
            var10002 = keyInfo2.getValue();
            keyInfo1 = var11.getP();
            return new DHPublicKeyParameters(var10002, new DHParameters(keyInfo1, var11.getG()));
         }
      } else {
         RSAPublicKeyStructure var9;
         var9 = new RSAPublicKeyStructure.<init>((ASN1Sequence)keyInfo.getPublicKey());
         keyInfo1 = var9.getModulus();
         var10 = var9.getPublicExponent();
         return new RSAKeyParameters(false, keyInfo1, var10);
      }
   }
}
